@@ -7,15 +7,16 @@
 #' @return Object of \code{\link{R6Class}} for modelling an ISOTypeName
 #' @format \code{\link{R6Class}} object.
 #'
-#' @field aName
+#' @field aName [\code{\link{character}}] the type name 
 #'
 #' @section Methods:
 #' \describe{
 #'  \item{\code{new(xml, aName)}}{
-#'    This method is used to instantiate an ISOTypeName
+#'    This method is used to instantiate an \code{\link{ISOTypeName}}
 #'  }
-#'  \item{\code{setName(aName)}}{
-#'    Sets the aName
+#'  \item{\code{setName(aName, locales)}}{
+#'    Sets the aName. Locale names can be specified as \code{list}
+#'    with the \code{locales} argument.
 #'  }
 #' }
 #' 
@@ -47,8 +48,11 @@ ISOTypeName <- R6Class("ISOTypeName",
      },
      
      #setName
-     setName = function(aName){
+     setName = function(aName, locales = NULL){
        self$aName <- aName
+       if(!is.null(locales)){
+         self$aName <- self$createLocalisedProperty(aName, locales)
+       }
      }
    )         
 )
\ No newline at end of file
