@@ -10,6 +10,8 @@ require(XML)
 context("GMLAbstractCRS")
 
 test_that("encoding",{
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   
   #encoding
   gml <- GMLAbstractCRS$new()
