@@ -10,6 +10,8 @@ require(XML)
 context("GMLCoordinateSystemAxis")
 
 test_that("encoding",{
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   
   #encoding
   gml <- GMLCoordinateSystemAxis$new(id = "ID1", uom = "m")
