@@ -11,6 +11,9 @@ context("GMLAstractGeneralOperationParameter")
 
 test_that("GMLAbstractGeneralOperationParameter",{
   
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
+  
   #encoding
   gml <- GMLAbstractGeneralOperationParameter$new()
   gml$setDescriptionReference("someref")
@@ -30,6 +33,9 @@ test_that("GMLAbstractGeneralOperationParameter",{
 
 test_that("GMLOperationParameter",{
   
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
+  
   #encoding
   gml <- GMLOperationParameter$new()
   gml$setDescriptionReference("someref")
@@ -49,6 +55,9 @@ test_that("GMLOperationParameter",{
 
 test_that("GMLOperationParameterGroup",{
   
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
+  
   #encoding
   gml <- GMLOperationParameterGroup$new()
   gml$setDescriptionReference("someref")
