@@ -9,7 +9,8 @@ require(testthat)
 context("ISORecord")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISORecord$new(value = "myvalue")
   expect_is(md, "ISORecord")
