@@ -9,7 +9,8 @@ require(testthat)
 context("ISOScope")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOScope$new()
   md$setLevel("dataset")
