@@ -8,7 +8,7 @@ require(testthat)
 
 context("ISOUnlimitedInteger")
 
-test_that("encoding",{
+test_that("encoding - finite number",{
   testthat::skip_on_cran()
   testthat::skip_on_travis()
   #encoding
@@ -23,4 +23,22 @@ test_that("encoding",{
   
   expect_true(ISOAbstractObject$compare(md, md2))
   
+})
+
+
+test_that("encoding - infinite number",{
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
+  #encoding
+  md <- ISOUnlimitedInteger$new(value = Inf)
+  expect_is(md, "ISOUnlimitedInteger")
+  xml <- md$encode()
+  expect_is(xml, "XMLInternalNode")
+  
+  #decoding
+  md2 <- ISOUnlimitedInteger$new(xml = xml)
+  xml2 <- md2$encode()
+  
+  expect_true(ISOAbstractObject$compare(md, md2))
+  
 })
\ No newline at end of file
